You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@arrow.apache.org by al...@apache.org on 2022/11/26 12:58:34 UTC

[arrow-datafusion] branch master updated: minor: correct name and typo (#4359)

This is an automated email from the ASF dual-hosted git repository.

alamb pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/arrow-datafusion.git


The following commit(s) were added to refs/heads/master by this push:
     new 3b7f76714 minor: correct name and typo (#4359)
3b7f76714 is described below

commit 3b7f76714c72a0488f141d2869ada737e0a0df39
Author: jakevin <ja...@gmail.com>
AuthorDate: Sat Nov 26 20:58:29 2022 +0800

    minor: correct name and typo (#4359)
    
    * minor: fix typo, redundant prefix
    
    * correct name
---
 datafusion/optimizer/src/eliminate_cross_join.rs   | 86 +++++++++++-----------
 datafusion/optimizer/src/limit_push_down.rs        |  2 +-
 datafusion/optimizer/src/optimizer.rs              |  4 +-
 .../optimizer/src/rewrite_disjunctive_predicate.rs |  4 +-
 datafusion/row/src/lib.rs                          |  7 +-
 5 files changed, 50 insertions(+), 53 deletions(-)

diff --git a/datafusion/optimizer/src/limit_push_down.rs b/datafusion/optimizer/src/limit_push_down.rs
index d6c1eae07..fd29015d5 100644
--- a/datafusion/optimizer/src/limit_push_down.rs
+++ b/datafusion/optimizer/src/limit_push_down.rs
@@ -362,7 +362,7 @@ mod test {
     }
 
     #[test]
-    fn multi_stage_limit_recurses_to_deeper_limit() -> Result<()> {
+    fn multi_stage_limit_recursive_to_deeper_limit() -> Result<()> {
         let table_scan = test_table_scan()?;
 
         let plan = LogicalPlanBuilder::from(table_scan)
diff --git a/datafusion/optimizer/src/optimizer.rs b/datafusion/optimizer/src/optimizer.rs
index fd70c805c..2ac3fda23 100644
--- a/datafusion/optimizer/src/optimizer.rs
+++ b/datafusion/optimizer/src/optimizer.rs
@@ -20,7 +20,7 @@
 use crate::common_subexpr_eliminate::CommonSubexprEliminate;
 use crate::decorrelate_where_exists::DecorrelateWhereExists;
 use crate::decorrelate_where_in::DecorrelateWhereIn;
-use crate::eliminate_cross_join::ReduceCrossJoin;
+use crate::eliminate_cross_join::EliminateCrossJoin;
 use crate::eliminate_filter::EliminateFilter;
 use crate::eliminate_limit::EliminateLimit;
 use crate::eliminate_outer_join::EliminateOuterJoin;
@@ -174,7 +174,7 @@ impl Optimizer {
             // subqueries to joins
             Arc::new(SimplifyExpressions::new()),
             Arc::new(EliminateFilter::new()),
-            Arc::new(ReduceCrossJoin::new()),
+            Arc::new(EliminateCrossJoin::new()),
             Arc::new(CommonSubexprEliminate::new()),
             Arc::new(EliminateLimit::new()),
             Arc::new(PropagateEmptyRelation::new()),
diff --git a/datafusion/optimizer/src/rewrite_disjunctive_predicate.rs b/datafusion/optimizer/src/rewrite_disjunctive_predicate.rs
index 7d7184b06..6a2ba2bde 100644
--- a/datafusion/optimizer/src/rewrite_disjunctive_predicate.rs
+++ b/datafusion/optimizer/src/rewrite_disjunctive_predicate.rs
@@ -50,7 +50,7 @@ use std::sync::Arc;
 /// main use is that it appears in TPCH Q19 and is required to avoid a
 /// CROSS JOIN.
 ///
-/// Specificially, Q19 has a WHERE clause that looks like
+/// Specifically, Q19 has a WHERE clause that looks like
 ///
 /// ```sql
 /// where
@@ -81,7 +81,7 @@ use std::sync::Arc;
 /// )
 /// ```
 ///
-/// Niavely planning this query will result in a CROSS join with that
+/// Naively planning this query will result in a CROSS join with that
 /// single large OR filter. However, rewriting it using the rewrite in
 /// this pass results in a proper join predicate, `p_partkey = l_partkey`:
 ///
diff --git a/datafusion/row/src/lib.rs b/datafusion/row/src/lib.rs
index 7d715f9da..aab929f27 100644
--- a/datafusion/row/src/lib.rs
+++ b/datafusion/row/src/lib.rs
@@ -386,11 +386,8 @@ mod tests {
     #[test]
     #[should_panic(expected = "not supported yet")]
     fn test_unsupported_type_read() {
-        let schema = Arc::new(Schema::new(vec![Field::new(
-            "a",
-            DataType::Decimal128(5, 2),
-            false,
-        )]));
+        let schema =
+            Arc::new(Schema::new(vec![Field::new("a", Decimal128(5, 2), false)]));
         let vector = vec![0; 1024];
         let row_offsets = vec![0];
         read_as_batch(&vector, schema, &row_offsets, Compact).unwrap();
diff --git a/datafusion/optimizer/src/eliminate_cross_join.rs b/datafusion/optimizer/src/eliminate_cross_join.rs
index 23e80ee54..83fc9e164 100644
--- a/datafusion/optimizer/src/eliminate_cross_join.rs
+++ b/datafusion/optimizer/src/eliminate_cross_join.rs
@@ -15,7 +15,7 @@
 // specific language governing permissions and limitations
 // under the License.
 
 //! Optimizer rule to reduce cross join to inner join if join predicates are available in filters.
 use crate::{utils, OptimizerConfig, OptimizerRule};
 use datafusion_common::{Column, DFSchema, DataFusionError, Result};
 use datafusion_expr::{
@@ -35,16 +35,16 @@ use datafusion_expr::logical_plan::JoinConstraint;
 use std::sync::Arc;
 
 #[derive(Default)]
-pub struct ReduceCrossJoin;
+pub struct EliminateCrossJoin;
 
-impl ReduceCrossJoin {
+impl EliminateCrossJoin {
     #[allow(missing_docs)]
     pub fn new() -> Self {
         Self {}
     }
 }
 
 /// Attempt to reorder join tp reduce cross joins to inner joins.
 /// for queries:
 /// 'select ... from a, b where a.x = b.y and b.xx = 100;'
 /// 'select ... from a, b where (a.x = b.y and b.xx = 100) or (a.x = b.y and b.xx = 200);'
@@ -54,7 +54,7 @@ impl ReduceCrossJoin {
 /// join nodes appropriately
 /// This fix helps to improve the performance of TPCH Q19. issue#78
 ///
-impl OptimizerRule for ReduceCrossJoin {
+impl OptimizerRule for EliminateCrossJoin {
     fn optimize(
         &self,
         plan: &LogicalPlan,
@@ -133,7 +133,7 @@ impl OptimizerRule for ReduceCrossJoin {
     }
 
     fn name(&self) -> &str {
-        "reduce_cross_join"
+        "eliminate_cross_join"
     }
 }
 
@@ -349,7 +349,7 @@ mod tests {
     };
 
     fn assert_optimized_plan_eq(plan: &LogicalPlan, expected: Vec<&str>) {
-        let rule = ReduceCrossJoin::new();
+        let rule = EliminateCrossJoin::new();
         let optimized_plan = rule
             .optimize(plan, &mut OptimizerConfig::new())
             .expect("failed to optimize plan");
@@ -366,11 +366,11 @@ mod tests {
     }
 
     #[test]
-    fn reduce_cross_with_simple_and() -> Result<()> {
+    fn eliminate_cross_with_simple_and() -> Result<()> {
         let t1 = test_table_scan_with_name("t1")?;
         let t2 = test_table_scan_with_name("t2")?;
 
         // could reduce to inner join since filter has Join predicates
         let plan = LogicalPlanBuilder::from(t1)
             .cross_join(&t2)?
             .filter(binary_expr(
@@ -393,11 +393,11 @@ mod tests {
     }
 
     #[test]
-    fn reduce_cross_with_simple_or() -> Result<()> {
+    fn eliminate_cross_with_simple_or() -> Result<()> {
         let t1 = test_table_scan_with_name("t1")?;
         let t2 = test_table_scan_with_name("t2")?;
 
         // could not reduce to inner join since filter OR expression and there is no common
         // Join predicates in left and right of OR expr.
         let plan = LogicalPlanBuilder::from(t1)
             .cross_join(&t2)?
@@ -421,11 +421,11 @@ mod tests {
     }
 
     #[test]
-    fn reduce_cross_with_and() -> Result<()> {
+    fn eliminate_cross_with_and() -> Result<()> {
         let t1 = test_table_scan_with_name("t1")?;
         let t2 = test_table_scan_with_name("t2")?;
 
         // could reduce to inner join
         let plan = LogicalPlanBuilder::from(t1)
             .cross_join(&t2)?
             .filter(binary_expr(
@@ -448,11 +448,11 @@ mod tests {
     }
 
     #[test]
-    fn reduce_cross_with_or() -> Result<()> {
+    fn eliminate_cross_with_or() -> Result<()> {
         let t1 = test_table_scan_with_name("t1")?;
         let t2 = test_table_scan_with_name("t2")?;
 
         // could reduce to inner join since Or predicates have common Join predicates
         let plan = LogicalPlanBuilder::from(t1)
             .cross_join(&t2)?
             .filter(binary_expr(
@@ -478,11 +478,11 @@ mod tests {
     }
 
     #[test]
-    fn reduce_cross_not_possible_simple() -> Result<()> {
+    fn eliminate_cross_not_possible_simple() -> Result<()> {
         let t1 = test_table_scan_with_name("t1")?;
         let t2 = test_table_scan_with_name("t2")?;
 
         // could not reduce to inner join
         let plan = LogicalPlanBuilder::from(t1)
             .cross_join(&t2)?
             .filter(binary_expr(
@@ -508,11 +508,11 @@ mod tests {
     }
 
     #[test]
-    fn reduce_cross_not_possible() -> Result<()> {
+    fn eliminate_cross_not_possible() -> Result<()> {
         let t1 = test_table_scan_with_name("t1")?;
         let t2 = test_table_scan_with_name("t2")?;
 
         // could not reduce to inner join
         let plan = LogicalPlanBuilder::from(t1)
             .cross_join(&t2)?
             .filter(binary_expr(
@@ -549,12 +549,12 @@ mod tests {
     ///   inner_join (ab)c and a.id = c.id
     ///     inner_join a b on a.id = b.id
     /// ```
-    fn reorder_join_to_reduce_cross_join_multi_tables() -> Result<()> {
+    fn reorder_join_to_eliminate_cross_join_multi_tables() -> Result<()> {
         let t1 = test_table_scan_with_name("t1")?;
         let t2 = test_table_scan_with_name("t2")?;
         let t3 = test_table_scan_with_name("t3")?;
 
         // could reduce to inner join
         let plan = LogicalPlanBuilder::from(t1)
             .cross_join(&t2)?
             .cross_join(&t3)?
@@ -581,13 +581,13 @@ mod tests {
     }
 
     #[test]
-    fn reduce_cross_join_multi_tables() -> Result<()> {
+    fn eliminate_cross_join_multi_tables() -> Result<()> {
         let t1 = test_table_scan_with_name("t1")?;
         let t2 = test_table_scan_with_name("t2")?;
         let t3 = test_table_scan_with_name("t3")?;
         let t4 = test_table_scan_with_name("t4")?;
 
         // could reduce to inner join
         let plan1 = LogicalPlanBuilder::from(t1)
             .cross_join(&t2)?
             .filter(binary_expr(
@@ -658,13 +658,13 @@ mod tests {
     }
 
     #[test]
-    fn reduce_cross_join_multi_tables_1() -> Result<()> {
+    fn eliminate_cross_join_multi_tables_1() -> Result<()> {
         let t1 = test_table_scan_with_name("t1")?;
         let t2 = test_table_scan_with_name("t2")?;
         let t3 = test_table_scan_with_name("t3")?;
         let t4 = test_table_scan_with_name("t4")?;
 
         // could reduce to inner join
         let plan1 = LogicalPlanBuilder::from(t1)
             .cross_join(&t2)?
             .filter(binary_expr(
@@ -678,7 +678,7 @@ mod tests {
             ))?
             .build()?;
 
         // could reduce to inner join
         let plan2 = LogicalPlanBuilder::from(t3)
             .cross_join(&t4)?
             .filter(binary_expr(
@@ -704,7 +704,7 @@ mod tests {
             ))?
             .build()?;
 
         // could not reduce to inner join
         let plan = LogicalPlanBuilder::from(plan1)
             .cross_join(&plan2)?
             .filter(binary_expr(
@@ -733,13 +733,13 @@ mod tests {
     }
 
     #[test]
-    fn reduce_cross_join_multi_tables_2() -> Result<()> {
+    fn eliminate_cross_join_multi_tables_2() -> Result<()> {
         let t1 = test_table_scan_with_name("t1")?;
         let t2 = test_table_scan_with_name("t2")?;
         let t3 = test_table_scan_with_name("t3")?;
         let t4 = test_table_scan_with_name("t4")?;
 
         // could reduce to inner join
         let plan1 = LogicalPlanBuilder::from(t1)
             .cross_join(&t2)?
             .filter(binary_expr(
@@ -753,7 +753,7 @@ mod tests {
             ))?
             .build()?;
 
         // could not reduce to inner join
         let plan2 = LogicalPlanBuilder::from(t3)
             .cross_join(&t4)?
             .filter(binary_expr(
@@ -775,7 +775,7 @@ mod tests {
             ))?
             .build()?;
 
         // could reduce to inner join
         let plan = LogicalPlanBuilder::from(plan1)
             .cross_join(&plan2)?
             .filter(binary_expr(
@@ -808,13 +808,13 @@ mod tests {
     }
 
     #[test]
-    fn reduce_cross_join_multi_tables_3() -> Result<()> {
+    fn eliminate_cross_join_multi_tables_3() -> Result<()> {
         let t1 = test_table_scan_with_name("t1")?;
         let t2 = test_table_scan_with_name("t2")?;
         let t3 = test_table_scan_with_name("t3")?;
         let t4 = test_table_scan_with_name("t4")?;
 
         // could not reduce to inner join
         let plan1 = LogicalPlanBuilder::from(t1)
             .cross_join(&t2)?
             .filter(binary_expr(
@@ -828,7 +828,7 @@ mod tests {
             ))?
             .build()?;
 
         // could reduce to inner join
         let plan2 = LogicalPlanBuilder::from(t3)
             .cross_join(&t4)?
             .filter(binary_expr(
@@ -854,7 +854,7 @@ mod tests {
             ))?
             .build()?;
 
         // could reduce to inner join
         let plan = LogicalPlanBuilder::from(plan1)
             .cross_join(&plan2)?
             .filter(binary_expr(
@@ -887,13 +887,13 @@ mod tests {
     }
 
     #[test]
-    fn reduce_cross_join_multi_tables_4() -> Result<()> {
+    fn eliminate_cross_join_multi_tables_4() -> Result<()> {
         let t1 = test_table_scan_with_name("t1")?;
         let t2 = test_table_scan_with_name("t2")?;
         let t3 = test_table_scan_with_name("t3")?;
         let t4 = test_table_scan_with_name("t4")?;
 
         // could reduce to inner join
         let plan1 = LogicalPlanBuilder::from(t1)
             .cross_join(&t2)?
             .filter(binary_expr(
@@ -907,10 +907,10 @@ mod tests {
             ))?
             .build()?;
 
         // could reduce to inner join
         let plan2 = LogicalPlanBuilder::from(t3).cross_join(&t4)?.build()?;
 
         // could reduce to inner join
         let plan = LogicalPlanBuilder::from(plan1)
             .cross_join(&plan2)?
             .filter(binary_expr(
@@ -970,19 +970,19 @@ mod tests {
     }
 
     #[test]
-    fn reduce_cross_join_multi_tables_5() -> Result<()> {
+    fn eliminate_cross_join_multi_tables_5() -> Result<()> {
         let t1 = test_table_scan_with_name("t1")?;
         let t2 = test_table_scan_with_name("t2")?;
         let t3 = test_table_scan_with_name("t3")?;
         let t4 = test_table_scan_with_name("t4")?;
 
         // could reduce to inner join
         let plan1 = LogicalPlanBuilder::from(t1).cross_join(&t2)?.build()?;
 
         // could reduce to inner join
         let plan2 = LogicalPlanBuilder::from(t3).cross_join(&t4)?.build()?;
 
         // could reduce to inner join
         let plan = LogicalPlanBuilder::from(plan1)
             .cross_join(&plan2)?
             .filter(binary_expr(
@@ -15,7 +15,7 @@
 // under the License.
 
-//! Optimizer rule to reduce cross join to inner join if join predicates are available in filters.
+//! Optimizer rule to eliminate cross join to inner join if join predicates are available in filters.
 use crate::{utils, OptimizerConfig, OptimizerRule};
 use datafusion_common::{Column, DFSchema, DataFusionError, Result};
@@ -35,16 +35,16 @@ use datafusion_expr::logical_plan::JoinConstraint;
 }
 
-/// Attempt to reorder join tp reduce cross joins to inner joins.
+/// Attempt to reorder join tp eliminate cross joins to inner joins.
 /// for queries:
 /// 'select ... from a, b where a.x = b.y and b.xx = 100;'
@@ -366,11 +366,11 @@ mod tests {
         let t2 = test_table_scan_with_name("t2")?;
 
-        // could reduce to inner join since filter has Join predicates
+        // could eliminate to inner join since filter has Join predicates
         let plan = LogicalPlanBuilder::from(t1)
             .cross_join(&t2)?
@@ -393,11 +393,11 @@ mod tests {
         let t2 = test_table_scan_with_name("t2")?;
 
-        // could not reduce to inner join since filter OR expression and there is no common
+        // could not eliminate to inner join since filter OR expression and there is no common
         // Join predicates in left and right of OR expr.
         let plan = LogicalPlanBuilder::from(t1)
@@ -421,11 +421,11 @@ mod tests {
         let t2 = test_table_scan_with_name("t2")?;
 
-        // could reduce to inner join
+        // could eliminate to inner join
         let plan = LogicalPlanBuilder::from(t1)
             .cross_join(&t2)?
@@ -448,11 +448,11 @@ mod tests {
         let t2 = test_table_scan_with_name("t2")?;
 
-        // could reduce to inner join since Or predicates have common Join predicates
+        // could eliminate to inner join since Or predicates have common Join predicates
         let plan = LogicalPlanBuilder::from(t1)
             .cross_join(&t2)?
@@ -478,11 +478,11 @@ mod tests {
         let t2 = test_table_scan_with_name("t2")?;
 
-        // could not reduce to inner join
+        // could not eliminate to inner join
         let plan = LogicalPlanBuilder::from(t1)
             .cross_join(&t2)?
@@ -508,11 +508,11 @@ mod tests {
         let t2 = test_table_scan_with_name("t2")?;
 
-        // could not reduce to inner join
+        // could not eliminate to inner join
         let plan = LogicalPlanBuilder::from(t1)
             .cross_join(&t2)?
@@ -549,12 +549,12 @@ mod tests {
         let t3 = test_table_scan_with_name("t3")?;
 
-        // could reduce to inner join
+        // could eliminate to inner join
         let plan = LogicalPlanBuilder::from(t1)
             .cross_join(&t2)?
@@ -581,13 +581,13 @@ mod tests {
         let t4 = test_table_scan_with_name("t4")?;
 
-        // could reduce to inner join
+        // could eliminate to inner join
         let plan1 = LogicalPlanBuilder::from(t1)
             .cross_join(&t2)?
@@ -658,13 +658,13 @@ mod tests {
         let t4 = test_table_scan_with_name("t4")?;
 
-        // could reduce to inner join
+        // could eliminate to inner join
         let plan1 = LogicalPlanBuilder::from(t1)
             .cross_join(&t2)?
@@ -678,7 +678,7 @@ mod tests {
             .build()?;
 
-        // could reduce to inner join
+        // could eliminate to inner join
         let plan2 = LogicalPlanBuilder::from(t3)
             .cross_join(&t4)?
@@ -704,7 +704,7 @@ mod tests {
             .build()?;
 
-        // could not reduce to inner join
+        // could not eliminate to inner join
         let plan = LogicalPlanBuilder::from(plan1)
             .cross_join(&plan2)?
@@ -733,13 +733,13 @@ mod tests {
         let t4 = test_table_scan_with_name("t4")?;
 
-        // could reduce to inner join
+        // could eliminate to inner join
         let plan1 = LogicalPlanBuilder::from(t1)
             .cross_join(&t2)?
@@ -753,7 +753,7 @@ mod tests {
             .build()?;
 
-        // could not reduce to inner join
+        // could not eliminate to inner join
         let plan2 = LogicalPlanBuilder::from(t3)
             .cross_join(&t4)?
@@ -775,7 +775,7 @@ mod tests {
             .build()?;
 
-        // could reduce to inner join
+        // could eliminate to inner join
         let plan = LogicalPlanBuilder::from(plan1)
             .cross_join(&plan2)?
@@ -808,13 +808,13 @@ mod tests {
         let t4 = test_table_scan_with_name("t4")?;
 
-        // could not reduce to inner join
+        // could not eliminate to inner join
         let plan1 = LogicalPlanBuilder::from(t1)
             .cross_join(&t2)?
@@ -828,7 +828,7 @@ mod tests {
             .build()?;
 
-        // could reduce to inner join
+        // could eliminate to inner join
         let plan2 = LogicalPlanBuilder::from(t3)
             .cross_join(&t4)?
@@ -854,7 +854,7 @@ mod tests {
             .build()?;
 
-        // could reduce to inner join
+        // could eliminate to inner join
         let plan = LogicalPlanBuilder::from(plan1)
             .cross_join(&plan2)?
@@ -887,13 +887,13 @@ mod tests {
         let t4 = test_table_scan_with_name("t4")?;
 
-        // could reduce to inner join
+        // could eliminate to inner join
         let plan1 = LogicalPlanBuilder::from(t1)
             .cross_join(&t2)?
@@ -907,10 +907,10 @@ mod tests {
             .build()?;
 
-        // could reduce to inner join
+        // could eliminate to inner join
         let plan2 = LogicalPlanBuilder::from(t3).cross_join(&t4)?.build()?;
 
@@ -907,10 +907,10 @@ mod tests {
         let plan2 = LogicalPlanBuilder::from(t3).cross_join(&t4)?.build()?;
 
-        // could reduce to inner join
+        // could eliminate to inner join
         let plan = LogicalPlanBuilder::from(plan1)
             .cross_join(&plan2)?
@@ -970,19 +970,19 @@ mod tests {
         let t4 = test_table_scan_with_name("t4")?;
 
-        // could reduce to inner join
+        // could eliminate to inner join
         let plan1 = LogicalPlanBuilder::from(t1).cross_join(&t2)?.build()?;
 
@@ -970,19 +970,19 @@ mod tests {
         let plan1 = LogicalPlanBuilder::from(t1).cross_join(&t2)?.build()?;
 
-        // could reduce to inner join
+        // could eliminate to inner join
         let plan2 = LogicalPlanBuilder::from(t3).cross_join(&t4)?.build()?;
 
@@ -970,19 +970,19 @@ mod tests {
         let plan2 = LogicalPlanBuilder::from(t3).cross_join(&t4)?.build()?;
 
-        // could reduce to inner join
+        // could eliminate to inner join
         let plan = LogicalPlanBuilder::from(plan1)
             .cross_join(&plan2)?